<?php
use Phalcon\Cache\Frontend\Data;
use Phalcon\Db\Adapter\Pdo\Mysql as DbAdapter;
use Phalcon\Events\Manager as EventsManager;
use Phalcon\Logger;
use Phalcon\Logger\Adapter\Stream as FileLogger; //    Phalcon\Session\Adapter\Files as SessionAdapterFiles,
set_time_limit(0);
ignore_user_abort(true);


const DIR_SRC     = __DIR__ . '/../';
const DIR_RUNTIME = DIR_SRC . '../runtime/';
const DIR_LOG     = DIR_RUNTIME . 'log';
const CLI_DIR_LOG = DIR_RUNTIME . 'log/cli/';
const SW_DIR_LOG  = DIR_RUNTIME . 'log/swoole/';

const APP_NAME = 'applet-cli';

//添加设置
$config = include __DIR__ . '/../common/config/config.php';
$loader = new Phalcon\Loader();
$loader->registerDirs([
    DIR_SRC . '/cli/tasks',
    DIR_SRC . '/common',
])->registerNamespaces([
  'SRVX' => $config->application->commDir,
  'App\constants' => $config->application->constantsDir,
])->register();

//inject config
$di = new Phalcon\DI\FactoryDefault\CLI();
$di->set('config', $config, true);
$di->set('request', 'Phalcon\Http\Request');
/**
 * 注入數據庫, debug模式记录查询SQL日志
 */
// debug模式记录查询SQL日志
$di->setShared('db', function () use ($config) {
    $db = new Phalcon\Db\Adapter\PdoFactory();
    $db = $db->newInstance($config->database->adapter, [
        'host'       => $config->database->host,
        'username'   => $config->database->username,
        'password'   => $config->database->password,
        'dbname'     => $config->database->dbname,
        'charset'    => $config->database->charset,
        'persistent' => $config->database->persistent,
        'options'    => [PDO::ATTR_TIMEOUT => 5]
    ]);
    if (DEBUG) {
        $adapter = new Phalcon\Logger\Adapter\Stream($config->database->log_file);
        $logger  = new Phalcon\Logger('messages', ['main' => $adapter,]);
        $manager = new Phalcon\Events\Manager();
        $manager->attach('db', function (Phalcon\Events\Event $event, $db) use ($logger) {
            ($event->getType() == 'beforeQuery') && $logger->info($db->getRealSQLStatement() . ' ' . json_encode($db->getSQLVariables(), 320));
        });
        $db->setEventsManager($manager);
    }
    return $db;
});
/**
 * debug模式使用File存储，正式使用redis
 */
$di->setShared('cache', function () use ($config) {
    // 默认15分钟
    $frontCache = new Data(['lifetime' => 900]);
    return new \Phalcon\Cache\Backend\Redis($frontCache, [
        'host'    => $config->redis->host,
        'port'    => $config->redis->port,
        'timeout' => $config->redis->timeout,
        'prefix'  => $config->redis->prefix,
    ]);
});
// Redis
$di->setShared('redis', function () use ($config) {
    $redis = new Redis();
    $redis->pconnect($config->redis->host, $config->redis->port, $config->redis->timeout);
    return $redis;
});
$di->setShared('s', function () {
  return new SRVX\Service;
});

//设置console
$console = new Phalcon\CLI\Console();
$console->setDI($di);
$di->set('console', $console, true);
$arguments = [];

foreach ($argv as $k => $arg) {
    if ($k == 1) {
        $arguments['task'] = $arg;
    } elseif ($k == 2) {
        $arguments['action'] = $arg;
    } elseif ($k >= 3) {
        $arguments['params'][] = $arg;
    }
}

try {
    $console->handle($arguments);
} catch (Phalcon\Exception $e) {
    $path = CLI_DIR_LOG . 'cli_' . date('Y_m_d') . '.log';
    // mkdir(CLI_DIR_LOG, true, 0777);
    // var_dump(realpath(CLI_DIR_LOG));die;
    $err  = "\n********************************************************\n[T] \t" . date('Y-m-d') . "\n[F] \t" . $e->getFile() . ' : ' . $e->getLine() . "\n[C] \t" . $e->getCode() . "\n[M] \t" . $e->getMessage() . PHP_EOL . $e->getTraceAsString() . PHP_EOL;

    file_put_contents($path, $err, FILE_APPEND);
}

