<?php

namespace SRVX\Service\Pay;

use SRVX\Service\BaseService;
use AlipaySystemOauthTokenRequest;
use AopClient;


class AlipayServiceToSystemOauthToken extends BaseService
{

    static private $config = [];
    static private $aopClient;

    public $gatewayUrl = 'https://openapi.alipay.com/gateway.do';
    public $apiVersion = '1.0';
    public $signType = 'RSA2';
    public $postCharset = 'UTF-8';
    public $format = 'json';

    public function __construct($config)
    {
        if (empty(self::$config)) {
            self::$config = $config;
        }
        $this->aopClient();
    }


    private function aopClient()
    {
        if (!self::$aopClient instanceof AopClient) {
            self::$aopClient                     = new AopClient();
            self::$aopClient->appId              = self::$config['pay_ali_app_id'];
            self::$aopClient->rsaPrivateKey      = self::$config['pay_ali_private_key'];
            self::$aopClient->alipayrsaPublicKey = self::$config['pay_ali_public_key'];
        }

        self::$aopClient->gatewayUrl  = $this->gatewayUrl;
        self::$aopClient->apiVersion  = $this->apiVersion;
        self::$aopClient->signType    = $this->signType;
        self::$aopClient->postCharset = $this->postCharset;
        self::$aopClient->format      = $this->format;
    }


    /**
     * [换取授权访问令牌]
     * @return [type] [description]
     */
    public function systemOauthToken($code, $refresh_token = "")
    {
        try {
            $request = new AlipaySystemOauthTokenRequest();
            if (empty($refresh_token)) {
                $request->setGrantType("authorization_code");
                $request->setCode($code);
            } else {
                $request->setGrantType("refresh_token");
                $request->setRefreshToken("refresh_token");
            }
            $response = self::$aopClient->execute($request);
            if (isset($response->error_response->code) and $response->error_response->code != 10000) {
                return $this->returnRes(false, $response->error_response->sub_msg ?? $response->error_response->msg, []);
            }
            $responseNode = str_replace(".", "_", $request->getApiMethodName()) . "_response";
            $responseData = json_decode(json_encode($response->$responseNode), true);
            return $this->returnRes(true, $responseData, $responseData);
        } catch (\Exception $e) {
            return $this->returnRes(false, $e->getMessage());
        }
    }
}