<?php

namespace SRVX\Service\Pay;

use SRVX\Model\App;
use SRVX\Model\MerchantAlipayAuthorize;
use SRVX\Model\OwnOrder;
use SRVX\Model\ProviderMode;
use SRVX\Model\UserMerchantOrder;
use SRVX\Model\UserMerchantTradeBatchTransferOrder;
use SRVX\Service\BaseService;

/**
 * demo
 * Class DemoService
 * @package SRVX\Service
 */
class PayService extends BaseService
{
    public function createOrder($data)
    {
        $model                = new UserMerchantOrder();
        $model->uid           = $data["uid"];
        $model->merchant_id   = $data["merchant_id"];
        $model->app_id        = $data["app_id"];
        $model->out_trade_no  = $data["out_trade_no"];
        $model->self_trade_no = $data["self_trade_no"];
        $model->total_amount  = $data["total_amount"];
        $model->subject       = $data["subject"];
        $model->pay_type      = $data["pay_type"];
        $model->kind          = $data["kind"];
        $model->ext           = $data["ext"] ?? "";
        $model->apply_data    = json_encode($data);
        $model->created_at    = date("Y-m-d H:i:s");
        $model->updated_at    = date("Y-m-d H:i:s");
        return $model->create() == false ? false : $model;
    }

    public function createTradeBatchTransferOrder($data, $args = [])
    {
        $model                     = new UserMerchantTradeBatchTransferOrder();
        $model->uid                = $data["uid"];
        $model->merchant_id        = $data["merchant_id"];
        $model->app_id             = $data["app_id"];
        $model->out_batch_no       = $data["out_batch_no"];
        $model->self_out_batch_no  = $data["self_out_batch_no"];
        $model->total_trans_amount = $data["total_trans_amount"];
        $model->total_count        = $data["total_count"];
        $model->order_title        = $data["order_title"];
        $model->batch_trans_id     = $data["batch_trans_id"];
        $model->pay_type           = $data["pay_type"];
        $model->type               = $data["type"];
        $model->trans_order_list   = json_encode($data["trans_order_list"]);
        $model->apply_data         = json_encode(["data" => $data, "args" => $args]);
        $model->created_at         = date("Y-m-d H:i:s");
        $model->updated_at         = date("Y-m-d H:i:s");
        return $model->create() == false ? false : $model;
    }

    public function getAppAuthToken($merchantSn)
    {
        $model = (new MerchantAlipayAuthorize())->findFirst("merchant_sn = '{$merchantSn}'");
        return !$model ? false : $model;
    }

    public function getPayConfig($appId)
    {
        $model = $this->modelsManager->createBuilder()
            ->addFrom(App::class, 'app')
            ->leftJoin(ProviderMode::class, 'app.id=mode.app_id', 'mode')
            ->columns('app.id,app.uid,app.app_id,app.pay_type,app.name,app.state,app.alipay_configure,app.wxpay_configure,app.remark, app.created_at, app.updated_at,app.deleted_at, mode.mode, mode.validate_time')
            ->where("app.app_id = '{$appId}' AND app.deleted_at IS NULL")
            ->getQuery()
            ->getSingleResult();
        return !$model ? false : $model;
    }

    /**
     * 支付異步回調第三方平台
     * @param $url
     * @param $params
     * @return bool
     */
    public function commonCurlNotifyUrl($url, $params): bool
    {
        try {
            $response = $this->curlPost($url, json_encode($params), false);
            logger(json_encode([
                "msg"      => "回調第三方平台結果",
                "url"      => $url,
                "params"   => $params,
                "response" => $response,
                "result"   => $response == "OK" || $response == "ok"
            ], 320), 'common_curl_notify_url_response', true);
            return $response == "OK" || $response == "ok";
        } catch (\Exception $exception) {
            logger(json_encode([
                "msg"       => "回調第三方平台異常",
                "url"       => $url,
                "params"    => $params,
                "exception" => $exception->getMessage(),
                "result"    => false
            ], 320), 'common_curl_notify_url_exception', true);
            return false;
        }
    }
}