<?php

namespace SRVX\Utils;
class Validate
{

    private static $instance = null;

    /**
     * @param bool $force 是否强制实例化
     * @return Validate|null
     */
    public static function init($force = false)
    {
        if ($force || self::$instance == null) {
            self::$instance = new self();
        }
        return self::$instance;
    }

    /**
     * 支付宝校验
     * @param $str
     * @return bool
     */
    public static function alipay($str)
    {
        return self::phone($str) || self::email($str);
    }

    /**
     * 中国地区手机校验
     * @param $str
     * @return int
     */
    public static function phone($str)
    {
        return preg_match('/^1[3456789]\d{9}$/', $str);
    }

    /**
     * 邮箱检验
     * @param $str
     * @return int
     */
    public static function email($str)
    {
        return preg_match('/^[a-z0-9]+([._-]*[a-z0-9])*@([a-z0-9]+[-a-z0-9]*[a-z0-9]+.){1,63}[a-z0-9]+$/', strtolower($str));
        //		return preg_match('/^[a-z]([._-]{0,1}[a-z]+)+@[0-9a-z]+(-{0,1}[a-z]+)+.[a-z]{2,8}$/i', strtolower($str));
    }

    /**
     * @param $url
     * @return mixed
     */
    public static function url($url)
    {
        return (bool)filter_var($url, FILTER_VALIDATE_URL);
    }

    /**
     * @param $ipAddr
     * @return mixed
     */
    public static function ip($ipAddr)
    {
        return (bool)filter_var($ipAddr, FILTER_VALIDATE_IP);
    }

    /**
     * 密码校验
     * @param string $pwd
     * @return bool
     */
    public static function passwdValid(string $pwd)
    {
        if (preg_match('/[^\w!@#$%\^&\*()+-=\[\]\;\',\.\/\{}|:"<>?]/', $pwd)) {
            return false;
        }
        //密码种类数
        return (bool)preg_match('/^(?![A-Z]+$)(?![\d]+$)(?![a-z]+$)(?![!@#$%^&\*()+-=\[\]\;\',\.\/\{}|:"<>?]+$)\\S{8,16}$/', $pwd);
    }

    /**
     * 微信用用户名通用
     * @param $str
     * @return int
     */
    public function username($str)
    {
        return preg_match('/^[\w\-]{5,15}$/i', $str);
    }

    /**
     * Chinese身份证验证
     * @param $str
     * @return false|int
     */
    public function idCard($str)
    {
        return preg_match('/(^\d{15}$)|(^\d{18}$)|(^\d{17}(\d|X|x)$)/', $str);
    }

    /**
     * 匹配QQ
     * @param $str
     * @return int
     */
    public function qq($str)
    {
        return preg_match('/^\d{5,12}$/', $str);
    }

    /**
     * 银行卡16或19位
     * @param $str
     * @return int
     */
    public function bankNum($str)
    {
        return preg_match('/^\d{16}|\d{19}$/', $str);
    }

    /**
     * @param $str
     * @return int
     */
    public function secAnswer($str)
    {
        //防sql注入
        return preg_match('/[\'\*\,\(\)\=]|select|update|insert/', $str);
    }

    public function passwordLen(string $pwd)
    {
        $len = mb_strlen($pwd);
        return $len < 8 || $len > 16;
    }

    public function passwdStrength(string $pwd)
    {
        //密码长度
        $len = mb_strlen($pwd, 'UTF-8');
        if ($len < 8 || $len > 16) {
            return false;
        }
        //密码字符
        //密码类型, 2种以上
        // '[\w!@#$%^&*()+-=\[\]\;\',./{}|:"<>?]';
    }

    public function naturalNum(string $str)
    {
        return preg_match('/^(0|[1-9][0-9]*)$/', $str);
    }

    public function integral(string $str)
    {
        return preg_match('/^\\+?(?!0)\\d{1,6}$/', $str);
    }

    public function floatNum(string $str)
    {
        return preg_match('/^(0|[1-9][0-9]{0,9})(\.[0-9]{1,2})?$/', $str);
    }

    public function notNullfloatNum(string $str)
    {
        return preg_match('/^([1-9][0-9]{0,9})(\.[0-9]{1,2})?$/', $str);
    }

    public function isDatetime($str)
    {
        return (date('Y-m-d H:i:s', strtotime($str)) == $str);
    }

    public function englishAndSpecialChar(string $str)
    {
        return preg_match('/^[a-zA-Z0-9_ ]+$/', $str);
    }
}